% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depth.fd.R
\name{FKS}
\alias{FKS}
\title{Fast kernel smoothing}
\usage{
FKS(T, X, Tout, kernel = c("uniform", "triangular", "Epanechnikov",
  "biweight", "triweight", "Gaussian"), m = 51, K = 20)
}
\arguments{
\item{T}{A vector of values in the interval [0,1].}

\item{X}{A vector of the observed values of the contaminated function, 
corresponding to \code{T}. Must have the same length as \code{T}.}

\item{Tout}{A vector of values in the interval [0,1] at which the
resulting smoothed function is evaluated.}

\item{kernel}{Kernel used for smoothing. Admissible values are \code{uniform}, 
\code{triangular}, \code{Epanechnikov}, \code{biweight}, \code{triweight} and \code{Gaussian}.
By default, \code{uniform} is used.}

\item{m}{Number of points in the grid for choosing the cross-validated bandwidth.}

\item{K}{Performs \code{K}-fold cross-validation based on randomly shuffled data.}
}
\value{
A vector corresponding to \code{Tout} of smoothed functional values.
}
\description{
Produces a kernel smoothed version of a function based on
the vectors given in the input. Bandwidth is selected using cross-validation.
}
\details{
A vector of the same length as \code{Tout}
corresponding to the values of the
function produced using kernel smoothing, is provided. Bandwidth is selected using the
\code{K}-fold cross-validation of randomly shuffled input values.
}
\examples{
d = 10
T = runif(d)
X = T^2+ rnorm(d,sd=.1)
Tout = seq(0,1,length=101)

plot(T,X)
lines(Tout,FKS(T,X,Tout))
lines(Tout,FKS(T,X,Tout,kernel="Epan"),col=2)
lines(Tout,FKS(T,X,Tout,kernel="Gaussian"),col=3)
lines(Tout,FKS(T,X,Tout,kernel="triweight"),col=4)
lines(Tout,FKS(T,X,Tout,kernel="biweight"),col=5)
lines(Tout,FKS(T,X,Tout,kernel="uniform"),col=2,lwd=2)
}
\author{
Stanislav Nagy, \email{stanislav.nagy@kuleuven.be}
}
\keyword{data}
\keyword{functional}
\keyword{kernel,}
\keyword{smoothing,}

