% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depth.fd.R
\name{L2metric}
\alias{L2metric}
\title{Fast computation of the \eqn{L^2} metric for sets of functional data}
\usage{
L2metric(A, B)
}
\arguments{
\item{A}{Functions of the first set, represented by a matrix of its functional values of 
size \code{m*d}. \code{m} stands for the number of functions, \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{m} functions are evaluated.}

\item{A}{Functions of the second set, represented by a matrix of its functional values of 
size \code{n*d}. \code{n} stands for the number of functions, \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{n} functions are evaluated. The grid of observation points for the 
functions \code{A} and \code{B} must be the same.}
}
\value{
A symmetric matrix of the distances of the functions of size \code{m*n}.
}
\description{
Returns the matrix of \eqn{L^2} distances between two sets of functional data.
}
\details{
For two sets of functional data of sizes \code{m} and \code{n}
represented by matrices of their functional values, 
this function returns the symmetric matrix of size \code{m*n} whose entry in the
\code{i}-th row and \code{j}-th column is the approximated \eqn{L^2} distance of the 
\code{i}-th function from the first set, and the \code{j}-th function from the second set.
This function is utilized in the computation of the h-mode depth.
}
\examples{
data(population)
A = as.matrix(population[1:20,1:66])
B = as.matrix(population[21:50,1:66])
L2metric(A,B)

}
\author{
Stanislav Nagy, \email{stanislav.nagy@kuleuven.be}
}
\seealso{
\code{\link{depth.hM}}
}
\keyword{\eqn{L^2}}
\keyword{data}
\keyword{functional}
\keyword{metric,}

