% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depth.fd.R
\name{depth.BD}
\alias{depth.BD}
\title{Band depth for functional data}
\usage{
depth.BD(A, B)
}
\arguments{
\item{A}{Functions whose depth is computed, represented by a matrix of its functional values of 
size \code{m*d}. \code{m} stands for the number of functions, \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{m} functions are evaluated.}

\item{B}{Random sample functions with respect to which the depth of \code{A} is computed. 
\code{B} is represented by a matrix of 
size \code{n*d}, where \code{n} is the sample size, and \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{n} functions are evaluated. The grid of observation points for the 
functions \code{A} and \code{B} must be the same.}
}
\value{
A vector of length \code{m} of the band depth values.
}
\description{
The (unadjusted) band depth 
for functional real-valued data of order \code{J=2}.
}
\details{
The function returns the vector of the sample (unadjusted) band depth values.
}
\examples{
data(population)
A = as.matrix(population[1:20,1:66])
B = as.matrix(population[21:50,1:66])
depth.BD(A,B)

}
\author{
Stanislav Nagy, \email{stanislav.nagy@kuleuven.be}
}
\references{
Lpez-Pintado, S. and Romo, J. (2009), On the concept of depth for functional data,
\emph{J. Amer. Statist. Assoc.} \bold{104} (486), 718  734.
}
\seealso{
\code{\link{depth.ABD}}, \code{\link{depth.fd1}}
}
\keyword{band}
\keyword{data}
\keyword{depth,}
\keyword{functional}

