% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depth.fd.R
\name{depth.RP2}
\alias{depth.RP2}
\title{Bivariate random projection depths for functional data}
\usage{
depth.RP2(A, B, nproj = 51)
}
\arguments{
\item{A}{Functions whose depth is computed, represented by an array of 
size \code{m*d*2}. \code{m} stands for the number of functions, \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{m} functions are evaluated. In the third dimension of the array, 
the functional values, and the values of the derivatives of these functions, are provided, respectively.}

\item{B}{Random sample functions with respect to which the depth of \code{A} is computed. 
\code{B} is represented by an array of 
size \code{n*d*2}, where \code{n} is the sample size, and \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{n} functions are evaluated.  In the third dimension of the array, 
the functional values, and the values of the derivatives of these functions, are provided, respectively.
The grid of observation points for the 
functions \code{A} and \code{B} must be the same.}

\item{nproj}{Number of projections taken in the computation of the double random projection depth. By default taken
to be \code{51}.}
}
\value{
Five vectors of length \code{m} are returned:
\itemize{
\item \code{Simpl_FD} the double random projection depth RP2 based on the bivariate simplicial depth,
\item \code{Half_FD} the double random projection depth RP2 based on the bivariate halfspace depth,
\item \code{hM_FD} the double random projection depth RP2 based on the bivariate h-mode depth,
\item \code{Simpl_DD} the double random projection depth RPD based on the univariate simplicial depth,
\item \code{Half_DD} the random projection depth RPD based on the univariate halfspace depth,
}
}
\description{
Double random projection depths of functional bivariate data (that is, data of the form \eqn{X:[a,b] \to R^2},
or \eqn{X:[a,b] \to R} and the derivative of \eqn{X}).
}
\details{
The function returns the vectors of sample double random projection depth values. 
The double random projection depths are described in Cuevas et al. (2007). They are of two types: RP2 type, and
RPD type. Both types of depths are based on bivariate projections of the bivariate functional data. 
These projections are taken randomly as a sample of standard
normal \code{d}-dimensional random variables, where \code{d} stands for the dimensionality of the discretized
functional data. For RP2 type depths, the average bivariate depth of the projected quantities is assessed.
For RPD type depths, further univariate projections of these bivariate projected quantities are evaluated, and
based on these final univariate quantities, the average univariate depth is computed.
}
\examples{
data(population)
A = as.matrix(population[1:20,1:66])
B = as.matrix(population[21:50,1:66])

A2 = derivatives.est(A,deriv=c(0,1))
B2 = derivatives.est(B,deriv=c(0,1))
depth.RP2(A2,B2)


}
\author{
Stanislav Nagy, \email{stanislav.nagy@kuleuven.be}
}
\references{
Cuevas, A., Febrero, M. and Fraiman, R.  (2007), Robust estimation and classification for functional data via projection-based depth notions, 
\emph{Computational Statistics} \bold{22} (3), 481  496.
}
\seealso{
\code{\link{depth.RP1}}
}
\keyword{data,}
\keyword{depth,}
\keyword{derivatives}
\keyword{double}
\keyword{functional}
\keyword{projection}
\keyword{random}

