% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depth.fd.R
\name{depth.fd2}
\alias{depth.fd2}
\title{Bivariate integrated and infimal depth for functional data}
\usage{
depth.fd2(A, B)
}
\arguments{
\item{A}{Functions whose depth is computed, represented by an array of 
size \code{m*d*2}. \code{m} stands for the number of functions, \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{m} functions are evaluated. In the third dimension of the array, 
the functional values, and the values of the derivatives of these functions, are provided, respectively.}

\item{B}{Random sample functions with respect to which the depth of \code{A} is computed. 
\code{B} is represented by an array of 
size \code{n*d*2}, where \code{n} is the sample size, and \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{n} functions are evaluated.  In the third dimension of the array, 
the functional values, and the values of the derivatives of these functions, are provided, respectively.
The grid of observation points for the 
functions \code{A} and \code{B} must be the same.}
}
\value{
Four vectors of length \code{m} are returned:
\itemize{
\item \code{Simpl_FD} the integrated depth based on the bivariate simplicial depth,
\item \code{Half_FD} the integrated depth based on the bivariate halfspace depth,
\item \code{Simpl_ID} the infimal depth based on the bivariate simplicial depth,
\item \code{Half_ID} the infimal depth based on the bivariate halfspace depth.
}
In addition, two vectors of length \code{m} of the relative area of smallest depth values is returned:
\itemize{
\item \code{Simpl_IA} the proportions of points at which the depth \code{Simpl_ID} was attained,
\item \code{Half_IA} the proportions of points at which the depth \code{Half_ID} was attained.
}
The values \code{Simpl_IA} and \code{Half_IA} are always in the interval [0,1]. 
They introduce ranking also among functions having the same
infimal depth value - if two functions have the same infimal depth, the one with larger infimal area
\code{IA} is said to be less central.
}
\description{
Integrated and infimal depths 
of functional bivariate data (that is, data of the form \eqn{X:[a,b] \to R^2},
or \eqn{X:[a,b] \to R} and the derivative of \eqn{X}) based on the
bivariate halfspace and simplicial depths.
}
\details{
The function returns the vectors of sample integrated and infimal depth values.
}
\examples{
data(population)
A = as.matrix(population[1:20,1:66])
B = as.matrix(population[21:50,1:66])

A2 = derivatives.est(A,deriv=c(0,1))
B2 = derivatives.est(B,deriv=c(0,1))
depth.fd2(A2,B2)

}
\author{
Stanislav Nagy, \email{stanislav.nagy@kuleuven.be}
}
\references{
Nagy, S., Gijbels, I. and Hlubinka, D.  (2016), Depth-based recognition of shape outlying functions, \emph{Under review}.
}
\seealso{
\code{\link{depth.fd1}}, \code{\link{infimalRank}}
}
\keyword{data,}
\keyword{depth,}
\keyword{derivatives}
\keyword{functional}
\keyword{infimal}
\keyword{integrated}

