% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depth.fd.R
\name{depth.hM}
\alias{depth.hM}
\title{h-mode depth for functional data}
\usage{
depth.hM(A, B, norm = c("C", "L2"), q = 0.2)
}
\arguments{
\item{A}{Functions whose depth is computed, represented by a matrix of its functional values of 
size \code{m*d}. \code{m} stands for the number of functions, \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{m} functions are evaluated.}

\item{B}{Random sample functions with respect to which the depth of \code{A} is computed. 
\code{B} is represented by a matrix of
size \code{n*d}, where \code{n} is the sample size, and \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{n} functions are evaluated. The grid of observation points for the 
functions \code{A} and \code{B} must be the same.}

\item{norm}{The norm used for the computation of the depth. Two possible 
choices are implemented: \code{C} for the uniform norm of continuous functions, 
and \code{L2} for the \eqn{L^2} norm of integrable functions.}

\item{q}{The quantile used to determine the value of the bandwidth \eqn{h}
in the computation of the h-mode depth. \eqn{h} is taken as the \code{q}-quantile of
all non-zero distances between the functions \code{B}. By default, this value is set
to \code{q=0.2}, in accordance with the choice of Cuevas et al. (2007).}
}
\value{
A vector of length \code{m} of the h-mode depth values.
}
\description{
The h-mode depth of functional real-valued data.
}
\details{
The function returns the vectors of the sample h-mode depth values. The kernel 
used in the evaluation is the standard Gaussian kernel, the bandwidth value is chosen
as a quantile of the non-zero distances between the random sample curves.
}
\examples{
data(population)
A = as.matrix(population[1:20,1:66])
B = as.matrix(population[21:50,1:66])
depth.hM(A,B)
depth.hM(A,B,norm="L2")
}
\author{
Stanislav Nagy, \email{stanislav.nagy@kuleuven.be}
}
\references{
Cuevas, A., Febrero, M. and Fraiman, R.  (2007), Robust estimation and classification for functional data via projection-based depth notions, 
\emph{Computational Statistics} \bold{22} (3), 481  496.
}
\keyword{data}
\keyword{depth,}
\keyword{functional}
\keyword{h-mode}

