% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depth.fd.R
\name{depth.hM2}
\alias{depth.hM2}
\title{Bivariate h-mode depth for functional data based on the \eqn{L^2} metric}
\usage{
depth.hM2(A, B, q = 0.2)
}
\arguments{
\item{A}{Functions whose depth is computed, represented by an array of 
size \code{m*d*2}. \code{m} stands for the number of functions, \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{m} functions are evaluated. In the third dimension of the array, 
the functional values, and the values of the derivatives of these functions, are provided, respectively.}

\item{B}{Random sample functions with respect to which the depth of \code{A} is computed. 
\code{B} is represented by an array of 
size \code{n*d*2}, where \code{n} is the sample size, and \code{d}
is the number equidistant points in the domain of the data at which the functional
values of the \code{n} functions are evaluated.  In the third dimension of the array, 
the functional values, and the values of the derivatives of these functions, are provided, respectively.
The grid of observation points for the 
functions \code{A} and \code{B} must be the same.}

\item{q}{The quantile used to determine the value of the bandwidth \eqn{h}
in the computation of the h-mode depth. \eqn{h} is taken as the \code{q}-quantile of
all non-zero distances between the functions \code{B}. By default, this value is set
to \code{q=0.2}, in accordance with the choice of Cuevas et al. (2007).}
}
\value{
Three vectors of length \code{m} of h-mode depth values are returned:
\itemize{
\item \code{hM} the unscaled h-mode depth,
\item \code{hM_norm} the h-mode depth \code{hM} linearly transformed so that its range is [0,1],
\item \code{hM_norm2} the h-mode depth \code{FD} linearly transformed by a transformation such that 
   the range of the h-mode depth of \code{B} with respect to \code{B} is [0,1]. This depth may give negative values.
}
}
\description{
The h-mode depth 
of functional bivariate data (that is, data of the form \eqn{X:[a,b] \to R^2},
or \eqn{X:[a,b] \to R} and the derivative of \eqn{X}) based on the
\eqn{L^2} metric of functions.
}
\details{
The function returns the vectors of sample h-mode depth values. The kernel 
used in the evaluation is the standard Gaussian kernel, the bandwidth value is chosen
as a quantile of the non-zero distances between the random sample curves.
}
\examples{
data(population)
A = as.matrix(population[1:20,1:66])
B = as.matrix(population[21:50,1:66])

A2 = derivatives.est(A,deriv=c(0,1))
B2 = derivatives.est(B,deriv=c(0,1))

depth.hM2(A2,B2)

depth.hM2(A2,B2)$hM
depth.hM2(cbind(A2[,,1],A2[,,2]),cbind(B2[,,1],B2[,,2]))$hM
# the two expressions above should give the same result

}
\author{
Stanislav Nagy, \email{stanislav.nagy@kuleuven.be}
}
\references{
Cuevas, A., Febrero, M. and Fraiman, R.  (2007), Robust estimation and classification for functional data via projection-based depth notions, 
\emph{Computational Statistics} \bold{22} (3), 481  496.
}
\seealso{
\code{\link{depth.hM}}
}
\keyword{data,}
\keyword{depth,}
\keyword{derivatives}
\keyword{functional}
\keyword{h-mode}

